Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(720)

Unified Diff: chrome/browser/ui/views/frame/browser_view_layout.cc

Issue 63173016: DevTools: place DevTools WebContents underneath inspected WebContents. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/browser_view_layout.cc
diff --git a/chrome/browser/ui/views/frame/browser_view_layout.cc b/chrome/browser/ui/views/frame/browser_view_layout.cc
index bb05f6e583031e202df23863c3bf494b63e5304a..12f67f4475847a43cd3a3651aa7837a1beacef04 100644
--- a/chrome/browser/ui/views/frame/browser_view_layout.cc
+++ b/chrome/browser/ui/views/frame/browser_view_layout.cc
@@ -145,7 +145,6 @@ BrowserViewLayout::BrowserViewLayout()
toolbar_(NULL),
bookmark_bar_(NULL),
infobar_container_(NULL),
- contents_split_(NULL),
contents_container_(NULL),
download_shelf_(NULL),
immersive_mode_controller_(NULL),
@@ -163,7 +162,6 @@ void BrowserViewLayout::Init(
TabStrip* tab_strip,
views::View* toolbar,
InfoBarContainerView* infobar_container,
- views::View* contents_split,
ContentsContainer* contents_container,
ImmersiveModeController* immersive_mode_controller) {
delegate_.reset(delegate);
@@ -173,7 +171,6 @@ void BrowserViewLayout::Init(
tab_strip_ = tab_strip;
toolbar_ = toolbar;
infobar_container_ = infobar_container;
- contents_split_ = contents_split;
contents_container_ = contents_container;
immersive_mode_controller_ = immersive_mode_controller;
}
@@ -202,7 +199,7 @@ gfx::Size BrowserViewLayout::GetMinimumSize() {
}
// TODO: Adjust the minimum height for the find bar.
- gfx::Size contents_size(contents_split_->GetMinimumSize());
+ gfx::Size contents_size(contents_container_->GetMinimumSize());
int min_height = delegate_->GetTopInsetInBrowserView() +
tabstrip_size.height() + toolbar_size.height() +
@@ -366,7 +363,7 @@ void BrowserViewLayout::Layout(views::View* browser_view) {
int active_top_margin = GetContentsOffsetForBookmarkBar();
contents_container_->SetActiveTopMargin(active_top_margin);
top -= active_top_margin;
- LayoutContentsSplitView(top, bottom);
+ LayoutContentsContainerView(top, bottom);
// This must be done _after_ we lay out the WebContents since this
// code calls back into us to find the bounding box the find bar
@@ -520,14 +517,14 @@ int BrowserViewLayout::LayoutInfoBar(int top) {
return overlapped_top + height;
}
-void BrowserViewLayout::LayoutContentsSplitView(int top, int bottom) {
- // |contents_split_| contains web page contents and devtools.
+void BrowserViewLayout::LayoutContentsContainerView(int top, int bottom) {
+ // |contents_container_| contains web page contents and devtools.
// See browser_view.h for details.
- gfx::Rect contents_split_bounds(vertical_layout_rect_.x(),
- top,
- vertical_layout_rect_.width(),
- std::max(0, bottom - top));
- contents_split_->SetBoundsRect(contents_split_bounds);
+ gfx::Rect contents_container_bounds(vertical_layout_rect_.x(),
+ top,
+ vertical_layout_rect_.width(),
+ std::max(0, bottom - top));
+ contents_container_->SetBoundsRect(contents_container_bounds);
}
void BrowserViewLayout::UpdateTopContainerBounds() {
@@ -553,10 +550,6 @@ int BrowserViewLayout::GetContentsOffsetForBookmarkBar() {
return 0;
}
- // Dev tools.
- if (contents_split_->child_at(1) && contents_split_->child_at(1)->visible())
- return 0;
-
// Offset for the detached bookmark bar.
return bookmark_bar_->height() -
bookmark_bar_->GetFullyDetachedToolbarOverlap();

Powered by Google App Engine
This is Rietveld 408576698